@@ -24,12 +24,12 @@
 #include <tqregexp.h>
 
 // KDE includes
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kdirlister.h>
 #include <kiconloader.h>
-#include <klocale.h>
-#include <kio/previewjob.h>
-#include <kio/netaccess.h>
+#include <tdelocale.h>
+#include <tdeio/previewjob.h>
+#include <tdeio/netaccess.h>
 #include <tqptrlist.h>
 #include <kurldrag.h>
 #include <kurllabel.h>
@@ -41,10 +41,10 @@
 #include "krecursivelister.h"
 #include "threadedlister.h"
 
-using namespace KIO;
+using namespace TDEIO;
 
 KMyListBox::KMyListBox(TQWidget* parent, const char* name, WFlags fl)
-    :KListBox(parent, name, fl)
+    :TDEListBox(parent, name, fl)
 {
     m_running_lister_counter = 0;
 
@@ -86,7 +86,7 @@ void KMyListBox::setPreviewSize( int size )
 
 void KMyListBox::removeItem( int index )
 {
-    KListBox::removeItem( index );
+    TDEListBox::removeItem( index );
 }
 
 void KMyListBox::addFile( const KURL & filename, bool isfile )
@@ -140,13 +140,13 @@ void KMyListBox::addDir( const KURL & dirname, const TQString & filter, bool hid
     thl->setHidden( hidden );
     thl->setRecursive( recursively );
     
-    KApplication::setOverrideCursor( TQt::waitCursor );
+    TDEApplication::setOverrideCursor( TQt::waitCursor );
     thl->start();
 }
 
 void KMyListBox::addDirName( const KURL & dirname, const TQString & filter, bool hidden, bool recursive )
 {
-    KApplication::setOverrideCursor( TQt::waitCursor );            
+    TDEApplication::setOverrideCursor( TQt::waitCursor );            
 
     if( recursive ) {
         ThreadedLister* thl = new ThreadedLister( &m_add_mutex, &m_running_lister_counter, this );
@@ -178,7 +178,7 @@ void KMyListBox::dropEvent(TQDropEvent* e)
     if( KURLDrag::decode( e, list ) )
     {
         
-        KApplication::setOverrideCursor( TQt::waitCursor );
+        TDEApplication::setOverrideCursor( TQt::waitCursor );
 
         setUpdatesEnabled( false );
 
@@ -201,7 +201,7 @@ void KMyListBox::viewportMousePressEvent( TQMouseEvent* e )
    if( moving )
         move( index( itemAt( e->pos() ) ) );
     else {
-        KListBox::viewportMousePressEvent( e );
+        TDEListBox::viewportMousePressEvent( e );
         TQPoint p( e->pos() );
         TQListBoxItem *i = itemAt( p );
         if ( i ) {
@@ -213,7 +213,7 @@ void KMyListBox::viewportMousePressEvent( TQMouseEvent* e )
 
 void KMyListBox::viewportMouseMoveEvent( TQMouseEvent* e )
 {
-    if ( mousePressed && ( presspos - e->pos() ).manhattanLength() > KApplication::startDragDistance() ) {
+    if ( mousePressed && ( presspos - e->pos() ).manhattanLength() > TDEApplication::startDragDistance() ) {
         mousePressed = FALSE;
         TQListBoxItem *item = itemAt( presspos );
         if ( item ) {
@@ -226,13 +226,13 @@ void KMyListBox::viewportMouseMoveEvent( TQMouseEvent* e )
             ud->drag();
         }
     } else
-        KListBox::viewportMouseMoveEvent( e );
+        TDEListBox::viewportMouseMoveEvent( e );
 }
 
 void KMyListBox::viewportMouseReleaseEvent( TQMouseEvent* e )
 {
     mousePressed = FALSE;
-    KListBox::viewportMouseReleaseEvent( e );
+    TDEListBox::viewportMouseReleaseEvent( e );
 }
 
 void KMyListBox::keyPressEvent( TQKeyEvent* e )
@@ -297,7 +297,7 @@ void KMyListBox::moveMode()
 {
     if ( !moving ) {
         moving = true;
-        KApplication::setOverrideCursor( TQt::sizeAllCursor );
+        TDEApplication::setOverrideCursor( TQt::sizeAllCursor );
     }
 }
 
@@ -334,11 +334,11 @@ void KMyListBox::select( TQListBoxItem* item )
 
 void KMyListBox::preview( KURL::List list )
 {
-    KIO::PreviewJob* job = KIO::filePreview( list, previewSize, previewSize, 0, 100, false, true, 0 );
+    TDEIO::PreviewJob* job = TDEIO::filePreview( list, previewSize, previewSize, 0, 100, false, true, 0 );
     connect( job, TQT_SIGNAL( gotPreview( const KFileItem*, const TQPixmap &) ), this, TQT_SLOT( previewDone( const KFileItem*, const TQPixmap &) ) );
     connect( job, TQT_SIGNAL( failed( const KFileItem*)), this, TQT_SLOT( previewFailed( const KFileItem* ) ));
-    connect( job, TQT_SIGNAL( result( KIO::Job * ) ), this, TQT_SLOT( previewFinished() ) );
-    KApplication::setOverrideCursor( TQt::waitCursor );
+    connect( job, TQT_SIGNAL( result( TDEIO::Job * ) ), this, TQT_SLOT( previewFinished() ) );
+    TDEApplication::setOverrideCursor( TQt::waitCursor );
 }
 
 void KMyListBox::previewDone( const KFileItem* item, const TQPixmap &pixmap )
@@ -360,7 +360,7 @@ void KMyListBox::previewFailed( const KFileItem* item )
         if( url( i ) == item->url() ) {
             KMyListBoxItem* it = static_cast<KMyListBoxItem*>(this->item( i ));
             if( it ) {
-                it->setPixmap( item->pixmap( getPreviewSize(), KIcon::DefaultState ) );
+                it->setPixmap( item->pixmap( getPreviewSize(), TDEIcon::DefaultState ) );
             }
             break;
         }
@@ -369,7 +369,7 @@ void KMyListBox::previewFailed( const KFileItem* item )
 void KMyListBox::previewFinished()
 {
     triggerUpdate( true ); //maybe false is enough
-    KApplication::restoreOverrideCursor();
+    TDEApplication::restoreOverrideCursor();
 }
 
 void KMyListBox::setPreview( bool prv )
@@ -401,7 +401,7 @@ void KMyListBox::setName( bool name )
 
 void KMyListBox::move( int i )
 {
-    KApplication::restoreOverrideCursor();
+    TDEApplication::restoreOverrideCursor();
     moving = false;
 
     if( !count() )
@@ -505,7 +505,7 @@ void KMyListBox::listerDone( ThreadedLister* lister )
  
     if( lister )   
         delete lister;
-    KApplication::restoreOverrideCursor();
+    TDEApplication::restoreOverrideCursor();
     
     setUpdatesEnabled( false );
     setPreview( KMyListBoxItem::preview() );
@@ -566,7 +566,7 @@ void KMyListBox::sortNummeric()
 
 void KMyListBox::sortList()
 {
-    KApplication::setOverrideCursor( TQt::WaitCursor );
+    TDEApplication::setOverrideCursor( TQt::WaitCursor );
 
     if( m_sorting == ASCENDING )
         sort( true );
@@ -577,7 +577,7 @@ void KMyListBox::sortList()
         unsigned int p = 0;
         for( unsigned int i = 0;i<count();i++)
         {
-            p = KApplication::random() % count();
+            p = TDEApplication::random() % count();
             if( p != i ) // This prevents the creation of a new ListBoxItem
                          // on the same position as before. It would not change
                          // the position of item, but cost a little bit of speed
@@ -612,7 +612,7 @@ void KMyListBox::sortList()
             }
     }
 
-    KApplication::restoreOverrideCursor();
+    TDEApplication::restoreOverrideCursor();
 }
 
 void KMyListBox::setSorting( int s )
@@ -697,13 +697,13 @@ const TQString KMyListBox::findNumInString( unsigned int pos, const TQString & s
 
 void KMyListBox::resizeEvent( TQResizeEvent* e )
 {
-    KListBox::resizeEvent( e );
+    TDEListBox::resizeEvent( e );
     positionLabel();
 }
 
 void KMyListBox::clear()
 {
-    KListBox::clear();
+    TDEListBox::clear();
     positionLabel();
 }
 
@@ -724,9 +724,9 @@ void KMyListBox::positionLabel()
 
 void KMyListBox::paintEvent( TQPaintEvent* e )
 {
-    //   qDebug("Updates=%i", (int)isUpdatesEnabled() );
+    //   tqDebug("Updates=%i", (int)isUpdatesEnabled() );
     //if( isUpdatesEnabled() )
-        KListBox::paintEvent( e );
+        TDEListBox::paintEvent( e );
 }
 
 KMyListBoxItem::KMyListBoxItem( const KMyListBoxItem* item )
@@ -780,7 +780,7 @@ void KMyListBoxItem::paint( TQPainter *painter )
         if( pm.isNull() ) {
             KFileItem item( KFileItem::Unknown, KFileItem::Unknown, m_url );
             KMyListBox* box = static_cast<KMyListBox*>(this->listBox());
-            setPixmap( item.pixmap( box->getPreviewSize(), KIcon::DefaultState ) );
+            setPixmap( item.pixmap( box->getPreviewSize(), TDEIcon::DefaultState ) );
         }
 
         yPos = ( itemHeight - pm.height() ) / 2;
